@@ -443,6 +443,8 @@ class Nested(Field):
         schema = self.schema
         if nested_obj is None:
             return None
+        if self.many and utils.is_iterable_but_not_string(nested_obj):
+            nested_obj = list(nested_obj)
         if not self.__updated_fields:
             schema._update_fields(obj=nested_obj, many=self.many)
             self.__updated_fields = True
@@ -645,7 +647,8 @@ class Number(Field):
 
     num_type = float
     default_error_messages = {
-        'invalid': 'Not a valid number.'
+        'invalid': 'Not a valid number.',
+        'too_large': 'Number too large.',
     }
 
     def __init__(self, as_string=False, **kwargs):
@@ -664,6 +667,8 @@ class Number(Field):
             return self._format_num(value)
         except (TypeError, ValueError):
             self.fail('invalid')
+        except OverflowError:
+            self.fail('too_large')
 
     def _to_string(self, value):
         return str(value)
