@@ -355,15 +355,6 @@ class BaseSchema(base.SchemaABC):
             )
         self.prefix = prefix
         self.strict = strict if strict is not None else self.opts.strict
-        if self.strict is False:
-            warnings.warn(
-                'strict=False is not recommended. In marshmallow 3.0, schemas will '
-                'always be strict. See '
-                'https://marshmallow.readthedocs.io/'
-                'en/latest/upgrading.html#schemas-are-always-strict',
-                ChangedInMarshmallow3Warning
-            )
-
         self.ordered = self.opts.ordered
         self.load_only = set(load_only) or set(self.opts.load_only)
         self.dump_only = set(dump_only) or set(self.opts.dump_only)
@@ -758,7 +749,7 @@ class BaseSchema(base.SchemaABC):
                 if set_operation == 'union':
                     new_options |= self.set_class(original_options)
                 if set_operation == 'intersection':
-                        new_options &= self.set_class(original_options)
+                    new_options &= self.set_class(original_options)
             setattr(self.declared_fields[key], option_name, new_options)
 
     def _update_fields(self, obj=None, many=False):
@@ -825,23 +816,14 @@ class BaseSchema(base.SchemaABC):
 
         :param set field_names: Field names to include in the final
             return dictionary.
+        :param object|Mapping|list obj The object to base filtered fields on.
         :returns: An dict of field_name:field_obj pairs.
         """
         if obj and many:
-            try:  # Homogeneous collection
-                # Prefer getitem over iter to prevent breaking serialization
-                # of objects for which iter will modify position in the collection
-                # e.g. Pymongo cursors
-                if hasattr(obj, '__getitem__') and callable(getattr(obj, '__getitem__')):
-                    try:
-                        obj_prototype = obj[0]
-                    except KeyError:
-                        obj_prototype = next(iter(obj))
-                else:
-                    obj_prototype = next(iter(obj))
-            except (StopIteration, IndexError):  # Nothing to serialize
+            try:  # list
+                obj = obj[0]
+            except IndexError:  # Nothing to serialize
                 return dict((k, v) for k, v in self.declared_fields.items() if k in field_names)
-            obj = obj_prototype
         ret = self.dict_class()
         for key in field_names:
             if key in self.declared_fields:
